
using PackageKit;

namespace AppStore {
    public enum LoadingType {
        PACKAGES, // Loaded packages
        CATEGORIES, // Loaded categories
        DETAILS, // Loading details
        REPOS, // Loading repo list
        INSTALL,
        REMOVE, // Installed or so
        UPDATES,
        CANCEL, // When transaction is cancelled
        SEARCH; // When it is searching apps
    }
    
    public enum ErrorType {
        COULD_NOT_GET_LOCK;
    }
    
    public enum ActionType {
        INSTALL,
        REMOVE;
    }
    
    public enum ResponseId {
        INFO,
        INSTALL;
    }
    
    /**
     * The skeleton of real Apps
     */
    public class ModelApp : Object {
        public string id;
        public string name;
        public string description;
        public string icon;
    }
    
    public class Category : Object {
        public string id;
        public string name;
        public string summary;
        public string icon;
        public int records;
        
        public Category (string id, string name, string summary, string icon, int records = 0) {
            this.id = id;
            this.name = name;
            this.summary = summary;
            this.icon = icon;
            this.records = records;
        }
    }
    
    public class App : Object {
        public PackageKit.Package package;
        public string id { get; private set; } // A valid id retrieved from a PkPackage
        public string name { get; private set; }
        public string summary { get; private set; }
        public string icon { get; set; }
        public string description { get; private set; }
        public uint info { get; private set; }
        public string version { get; private set; }
        public string license { get; private set; }
        public string url { get; private set; }
        public int size { get; private set; }
        
        public App (string id, string name, string summary, string icon, PackageKit.Package pkg, PackageKit.Details details) {
            this.package = pkg;
            this.id = id;
            this.name = name;
            this.summary = summary;
            this.icon = icon;
            description = details.description;
            info = pkg.info;
            version = pkg.get_version ();
            license = details.license;
            size = (int) details.size;
            url = details.url;
        }

    }   
}

